@@ -2,7 +2,4 @@
 ### The is.unsorted() generic
 ### -------------------------------------------------------------------------
 
-setGeneric("is.unsorted",
-           function(x, na.rm = FALSE, strictly = FALSE)
-           standardGeneric("is.unsorted"),
-           signature = "x")
+setGeneric("is.unsorted", signature = "x")
