@@ -6,3 +6,9 @@ setGeneric("strand", function(x, ...) standardGeneric("strand"))
 
 setGeneric("strand<-", function(x, ..., value) standardGeneric("strand<-"))
 
+unstrand <- function(x)
+{
+    strand(x) <- "*"
+    x
+}
+
